==> kolourpaint-4.14.3.tar.xz: kolourpaint-4.14.3/widgets/kpTransparentColorCell.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpTransparentColorCell_H
#define kpTransparentColorCell_H


#include <qframe.h>


class kpColor;


class kpTransparentColorCell : public QFrame
{
Q_OBJECT

public:
    kpTransparentColorCell (QWidget *parent);

    virtual QSize sizeHint () const;

signals:
    void transparentColorSelected (int mouseButton);

    // lazy
    void foregroundColorChanged (const kpColor &color);
    void backgroundColorChanged (const kpColor &color);

protected:
    virtual void mousePressEvent (QMouseEvent *e);
    virtual void contextMenuEvent (QContextMenuEvent *e);
    virtual void mouseReleaseEvent (QMouseEvent *e);

    virtual void paintEvent (QPaintEvent *e);

    QPixmap m_pixmap;
};


#endif  // kpTransparentColorCell_H

==> kolourpaint_17.12.3.orig.tar.xz: kolourpaint-17.12.3/widgets/kpTransparentColorCell.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpTransparentColorCell_H
#define kpTransparentColorCell_H


#include <qframe.h>


class kpColor;


class kpTransparentColorCell : public QFrame
{
Q_OBJECT

public:
    kpTransparentColorCell (QWidget *parent);

    QSize sizeHint () const Q_DECL_OVERRIDE;

signals:
    void transparentColorSelected (int mouseButton);

    // lazy
    void foregroundColorChanged (const kpColor &color);
    void backgroundColorChanged (const kpColor &color);

protected:
    void mousePressEvent (QMouseEvent *e) Q_DECL_OVERRIDE;
    void contextMenuEvent (QContextMenuEvent *e) Q_DECL_OVERRIDE;
    void mouseReleaseEvent (QMouseEvent *e) Q_DECL_OVERRIDE;

    void paintEvent (QPaintEvent *e) Q_DECL_OVERRIDE;

    QPixmap m_pixmap;
};


#endif  // kpTransparentColorCell_H
